@@ -7,9 +7,8 @@ from collections import namedtuple
 from datetime import datetime
 from io import BytesIO, StringIO
 
-import tqdm
-
 import rebotics_sdk
+import tqdm
 
 logger = logging.getLogger(__name__)
 
@@ -154,7 +153,7 @@ class ClassificationDatabasePacker(BaseClassificationDatabasePacker):
                     raise ClassificationDatabaseException("Numeric order collision. {}".format(f.name))
 
                 known_order.add(numeric_order)
-                self.images.append(ImageEntry(f.name, f, numeric_order))
+                self.images.append(ImageEntry(f.name, str(f), numeric_order))
 
         # repack based on the filename and it's numeric value
         self.images.sort(key=lambda i: i.order)  # sort by numeric value of the filename
