@@ -246,7 +246,7 @@ def configure(ctx, user, password, host):
         date=datetime.now().strftime('%c'),
         **response
     )
-    click.echo('Saved configuration for {} in {}'.format(ctx.key, ctx.config_provider.filepath), err=True)
+    click.echo('Saved configuration for {} in {}'.format(ctx.role, ctx.config_provider.filepath), err=True)
     ctx.format_result(response)
 
 
