@@ -74,22 +74,26 @@ class ReboticsScriptsConfiguration(DumpableConfiguration):
 class ReboticsCLIContext(object):
     configuration_class = ReboticsScriptsConfiguration
 
-    def __init__(self, retailer, format, verbose, config_path, provider_class):
-        self.key = retailer
+    def __init__(self, role, format, verbose, config_path, provider_class):
+        self.role = role
         self.format = format
         self.verbose = verbose
         self.config_path = config_path
         self.provider_class = provider_class
         self.config_provider = self.configuration_class(self.config_path, self.provider_class)
-        self.configuration_class = ReboticsScriptsConfiguration
         self.config = self.config_provider.config
 
     @property
     def provider(self):
-        return self.config_provider.get_provider(self.key)
+        provider = self.config_provider.get_provider(self.role)
+
+        if provider is None:
+            raise click.ClickException('Role {0} is not configured.\n'
+                                       'Run: \n<app> -r {0} configure'.format(self.role))
+        return provider
 
     def update_configuration(self, **configuration):
-        self.config_provider.update_configuration(self.key, **configuration)
+        self.config_provider.update_configuration(self.role, **configuration)
 
     def format_result(self, items, max_column_length=30, keys_to_skip=None):
         if self.format == 'json':
@@ -121,15 +125,16 @@ def read_saved_role(command_name):
         return None
     role = roles.get(command_name)
     if role is not None:
-        click.echo('Using previous role: {}'.format(role))
+        click.echo('Using previous role: {}'.format(role), err=True)
     return role
 
 
 def process_role(ctx, role, command_name):
-    if role is None:
+    if not role:
         if ctx.invoked_subcommand != 'roles':
-            click.echo('You have not specified role to use. User `roles` subcommand to see what roles are available')
-            ctx.exit(1)
+            raise click.ClickException(
+                'You have not specified role to use. User `roles` sub command to see what roles are available'
+            )
     else:
         states.update_configuration('roles', **{command_name: role})
 
